@@ -5,27 +5,33 @@ import numpy as np
 import pandas as pd
 
 def fill_zero(df):
+    """Fill NaN with zero."""
     df = df.fillna(0)
     return df
 
 def fill_forward(df):
+    """Fill NaN with previous values."""
     df = df.fillna(method='ffill')
     df = df.fillna(method='bfill')
     return df
     
 def fill_mean(df):
+    """Fill NaN with mean."""
     df = df.fillna(df.mean().to_dict())
     return df
 
 def fill_median(df):
+    """Fill NaN with median."""
     df = df.fillna(df.median().to_dict())
     return df
     
 def rolling_mean(df, window: int = 10):
-    df= df.fillna(df.rolling(window = window, min_periods=1).mean())
+    """Fill NaN with mean of last window values."""
+    df= df.fillna(df.rolling(window = window, min_periods=1).mean()).fillna(df.mean().to_dict())
     return df
     
 def biased_ffill(df, mean_weight: float = 1):
+    """Fill NaN with average of last value and mean."""
     df_mean = fill_mean(df)
     df_ffill = fill_forward(df)
     df = ((df_mean * mean_weight) + df_ffill)/(1 + mean_weight)
@@ -33,32 +39,38 @@ def biased_ffill(df, mean_weight: float = 1):
 
 def fake_date_fill(df, back_method: str = 'slice'):
     """
-    Returns a dataframe where na values are removed and values shifted forward.
-    Thus, values will likely have incorrect timestamps!
+    Return a dataframe where na values are removed and values shifted forward.
     
-    :param back_method: - how to deal with tails due to different length series
-        - 'bfill' -back fill the last value
-        - 'slice' - drop any rows with any na
-        - 'keepNA' - keep the lagging na
-    :type back_method: str
-    """    
+    Warnings:
+        Thus, values will likely have incorrect timestamps!
+    
+    Args:
+        back_method (str): how to deal with tails left by shifting NaN
+            - 'bfill' -back fill the last value
+            - 'slice' - drop any rows with any na
+            - 'keepNA' - keep the lagging na
+    """
     df_index = df.index.to_series().copy()
     df = df.sort_index(ascending=False)
     df = df.apply(lambda x: pd.Series(x.dropna().values))
     df = df.sort_index(ascending=False)
     df.index = df_index.tail(len(df.index))    
     df = df.dropna(how = 'all', axis = 0)
-    
+
     if back_method == 'bfill':
         df = df.fillna(method = 'bfill')
-    if back_method == 'slice':
+        return df
+    elif back_method == 'slice':
         df = df.dropna(how = 'any', axis = 0)
-    if back_method == 'keepNA':
-        pass
-    return df
+        return df
+    elif back_method == 'keepNA':
+        return df
+    else:
+        print('back_method not recognized in fake_date_fill')
+        return df
 
 def FillNA(df, method: str = 'ffill', window: int = 10):
-    """Fill NA values using different methods
+    """Fill NA values using different methods.
     
     Args:
         method (str):
